EncryptedMessage

Struct EncryptedMessage 

pub struct EncryptedMessage { /* private fields */ }
Encrypted message structure.

This struct is serialized into Vec<u8> (and deserialized from Vec<u8>). In order to send an EncryptedMessage to a remote receiver, use let bin = encrypted_message.serialize();. Then, the receiver should deserialize it by let encrypted_message = EncryptedMessage::deserialize(bin);.

This struct includes Nonce, which is internally used when a receiver decrypt the encrypted message.

Implementations

Source

impl EncryptedMessage

pub fn serialize(self) -> Vec<u8>

Serialize this encrypted message into binary in order to send it to a remote receiver.

pub fn deserialize( serialized_encrypted_message: Vec<u8>, ) -> Result<EncryptedMessage, Error>

Deserializer function for a receiver.

Failures
pub fn nonce(&self) -> &[u8]

Ref to XChaCha20 nonce (192-bit / 24-byte) used to create this encrypted message.

pub fn encrypted(&self) -> &[u8]

Ref to encrypted message.

pub fn len(&self) -> usize

Payload size in bytes.